@@ -21,7 +21,7 @@
  #include <libdefs.h>
 #endif
 #include <bzero.h>
-#include <swap.h>
+#include <xmemory.h>
 #include <lcrypt.h>
 #include <blowfish.h>
 #include <3-way.h>
@@ -32,7 +32,7 @@
 #include <tean.h>
 #include <twofish.h>
 
-#define MAX_THREADS 100 /* After that pointers are being reused */
+#define MAX_THREADS 30000 /* After that pointers are being reused */
 
 /* I think now is re-entrant */
 
@@ -149,21 +149,21 @@ char *keyword1, *keyword2, *keyword3; /* For 3DES and safer*/
 unsigned char *skey=NULL;
 word8 twokey[16]; /* 128 bits */
 
-  saferkey=realloc(saferkey, (cur_thread+1)*sizeof(char*));
-  kn1=realloc(kn1, (cur_thread+1)*sizeof(char*));
-  kn2=realloc(kn2, (cur_thread+1)*sizeof(char*));
-  kn3=realloc(kn3, (cur_thread+1)*sizeof(char*));
-  c=realloc(c, (cur_thread+1) * sizeof(blf_ctx));
-  CT=realloc(CT, (cur_thread+1) * sizeof(TWOFISH_context));
-  ckey=realloc(ckey, (cur_thread+1) * sizeof(struct cast_key));
-  keyword_given=realloc(keyword_given, (cur_thread+1)*sizeof(char*));
-  algorithm_given=realloc(algorithm_given, (cur_thread+1)*sizeof(int));
+  saferkey=mxrealloc(saferkey, (cur_thread+1)*sizeof(char*));
+  kn1=mxrealloc(kn1, (cur_thread+1)*sizeof(char*));
+  kn2=mxrealloc(kn2, (cur_thread+1)*sizeof(char*));
+  kn3=mxrealloc(kn3, (cur_thread+1)*sizeof(char*));
+  c=mxrealloc(c, (cur_thread+1) * sizeof(blf_ctx));
+  CT=mxrealloc(CT, (cur_thread+1) * sizeof(TWOFISH_context));
+  ckey=mxrealloc(ckey, (cur_thread+1) * sizeof(struct cast_key));
+  keyword_given=mxrealloc(keyword_given, (cur_thread+1)*sizeof(char*));
+  algorithm_given=mxrealloc(algorithm_given, (cur_thread+1)*sizeof(int));
 
 
   if (get_key_size(algorithm) < lenofkey) lenofkey=get_key_size(algorithm);
   
   algorithm_given[cur_thread]=algorithm;
-  keyword_given[cur_thread]=calloc(1, get_key_size(algorithm));
+  keyword_given[cur_thread]=mxcalloc(1, get_key_size(algorithm));
   memmove(keyword_given[cur_thread], key, lenofkey);
   skey=keyword_given[cur_thread];
 
@@ -172,16 +172,16 @@ word8 twokey[16]; /* 128 bits */
   
    case DES:
       desinit(0);
-      kn1[cur_thread]=malloc(8*16*sizeof(char));
+      kn1[cur_thread]=mxmalloc(8*16*sizeof(char));
       
       des_setkey( (void*) kn1[cur_thread], (void *) keyword_given[cur_thread]);
       return cur_thread;
       break;
 
    case SAFER64:
-      keyword1=malloc(8);
+      keyword1=mxmalloc(8);
       memmove(keyword1, keyword_given[cur_thread], 8);
-      saferkey[cur_thread]=malloc(1 + SAFER_BLOCK_LEN * (1 + 2 * SAFER_MAX_NOF_ROUNDS));
+      saferkey[cur_thread]=mxmalloc(1 + SAFER_BLOCK_LEN * (1 + 2 * SAFER_MAX_NOF_ROUNDS));
 
       Safer_Init_Module();
       Safer_Expand_Userkey( (unsigned char*) keyword1,(unsigned char*) keyword1, SAFER_SK64_DEFAULT_NOF_ROUNDS, 1, saferkey[cur_thread]);
@@ -195,8 +195,8 @@ word8 twokey[16]; /* 128 bits */
 
    case SAFER128:
       Safer_Init_Module();
-      keyword1=malloc(8); keyword2=malloc(8);
-      saferkey[cur_thread]=malloc(1 + SAFER_BLOCK_LEN * (1 + 2 * SAFER_MAX_NOF_ROUNDS));
+      keyword1=mxmalloc(8); keyword2=mxmalloc(8);
+      saferkey[cur_thread]=mxmalloc(1 + SAFER_BLOCK_LEN * (1 + 2 * SAFER_MAX_NOF_ROUNDS));
       
       memmove(keyword1, skey, 8);
       memmove(keyword2, &skey[8], 8);
@@ -209,12 +209,12 @@ word8 twokey[16]; /* 128 bits */
       
    case TripleDES:
       desinit(0);
-      keyword1=calloc(1,8*sizeof(char)); 
-      keyword2=calloc(1,8*sizeof(char)); 
-      keyword3=calloc(1,8*sizeof(char));
-      kn1[cur_thread]=malloc(8*16*sizeof(char));
-      kn2[cur_thread]=malloc(8*16*sizeof(char));
-      kn3[cur_thread]=malloc(8*16*sizeof(char));
+      keyword1=mxcalloc(1,8*sizeof(char)); 
+      keyword2=mxcalloc(1,8*sizeof(char)); 
+      keyword3=mxcalloc(1,8*sizeof(char));
+      kn1[cur_thread]=mxmalloc(8*16*sizeof(char));
+      kn2[cur_thread]=mxmalloc(8*16*sizeof(char));
+      kn3[cur_thread]=mxmalloc(8*16*sizeof(char));
       
       /* If it returns 1 or -1 the key is too small */
 
@@ -545,9 +545,9 @@ cur_thread++;
 if (cur_thread < MAX_THREADS && finished_threads==0) {
 
 /* for cbc */
-  previous_ciphertext=realloc(previous_ciphertext, (cur_thread+1) * sizeof(word32*));
-  previous_cipher=realloc(previous_cipher, (cur_thread+1) * sizeof(word32*));
-  previous_plaintext=realloc(previous_plaintext, (cur_thread+1) * sizeof(word32*));
+  previous_ciphertext=mxrealloc(previous_ciphertext, (cur_thread+1) * sizeof(word32*));
+  previous_cipher=mxrealloc(previous_cipher, (cur_thread+1) * sizeof(word32*));
+  previous_plaintext=mxrealloc(previous_plaintext, (cur_thread+1) * sizeof(word32*));
 /* end cbc */
 
 }
@@ -567,9 +567,9 @@ else {
 
 
 /* For cbc */
-  previous_ciphertext[cur_thread]=calloc(1,get_block_size(algorithm));
-  previous_cipher[cur_thread]=malloc(get_block_size(algorithm));
-  previous_plaintext[cur_thread]=calloc(1,get_block_size(algorithm));
+  previous_ciphertext[cur_thread]=mxcalloc(1,get_block_size(algorithm));
+  previous_cipher[cur_thread]=mxmalloc(get_block_size(algorithm));
+  previous_plaintext[cur_thread]=mxcalloc(1,get_block_size(algorithm));
 
 /* End cbc */
 
@@ -671,10 +671,10 @@ cur_thread++;
 if (cur_thread < MAX_THREADS && finished_threads==0) {
 
 /* for cfb */
-  s_register=realloc(s_register, (cur_thread+1) * sizeof(char*));
-  enc_s_register=realloc(enc_s_register, (cur_thread+1) * sizeof(char*));  
-  enc_sd_register=realloc(enc_sd_register, (cur_thread+1) * sizeof(char*));  
-  sd_register=realloc(sd_register, (cur_thread+1) * sizeof(char*));
+  s_register=mxrealloc(s_register, (cur_thread+1) * sizeof(char*));
+  enc_s_register=mxrealloc(enc_s_register, (cur_thread+1) * sizeof(char*));  
+  enc_sd_register=mxrealloc(enc_sd_register, (cur_thread+1) * sizeof(char*));  
+  sd_register=mxrealloc(sd_register, (cur_thread+1) * sizeof(char*));
 /* end cfb */
 }
 else {
@@ -693,10 +693,10 @@ else {
 
 
 /* For cfb */
-  s_register[cur_thread]=malloc( get_block_size(algorithm));
-  sd_register[cur_thread]=malloc( get_block_size(algorithm));
-  enc_s_register[cur_thread]=malloc( get_block_size(algorithm));
-  enc_sd_register[cur_thread]=malloc( get_block_size(algorithm));
+  s_register[cur_thread]=mxmalloc( get_block_size(algorithm));
+  sd_register[cur_thread]=mxmalloc( get_block_size(algorithm));
+  enc_s_register[cur_thread]=mxmalloc( get_block_size(algorithm));
+  enc_sd_register[cur_thread]=mxmalloc( get_block_size(algorithm));
   memmove(sd_register[cur_thread], IV, get_block_size(algorithm));
   memmove(s_register[cur_thread], IV, get_block_size(algorithm));  
 
@@ -773,7 +773,7 @@ int mdecrypt_cfb(int td, void *plaintext,int len) /* plaintext is 1 byte (8bit c
 
 char* get_algorithms_name(int algorithm) {
 
-char *x=malloc(12);
+char *x=mxmalloc(12);
 
   switch(algorithm) {
    case DES:
