@@ -8,23 +8,25 @@
 # include <stdio.h>
 #endif
 
-#if SIZEOF_LONG_INT == 4
+#include <unistd.h>
+
+#if SIZEOF_UNSIGNED_LONG_INT == 4
  typedef unsigned long word32;
-#elif SIZEOF_INT == 4
+#elif SIZEOF_UNSIGNED_INT == 4
  typedef unsigned int word32;
 #else
 # error "Cannot find a 32 bit integer in your system, sorry."
 #endif
 
-#if SIZEOF_INT == 2
+#if SIZEOF_UNSIGNED_INT == 2
  typedef unsigned int word16;
-#elif SIZEOF_SHORT_INT == 2
+#elif SIZEOF_UNSIGNED_SHORT_INT == 2
  typedef unsigned short word16;
 #else 
 # error "Cannot find a 16 bit integer in your system, sorry."
 #endif
 
-#if SIZEOF_CHAR == 1
+#if SIZEOF_UNSIGNED_CHAR == 1
  typedef unsigned char word8; 
 #else
 # error "Cannot find an 8 bit char in your system, sorry."
