@@ -116,5 +116,26 @@
 # endif
 #endif
 
-extern char *getpass();
+/*extern char *getpass();*/
 extern char *crypt(); /* libufc */
+
+#if HAVE_TERMIOS_H
+# include <termios.h>
+# define STTY(fd, termio) tcsetattr(fd, TCSANOW, termio)
+# define GTTY(fd, termio) tcgetattr(fd, termio)
+# define TERMIO struct termios
+# define USE_TERMIOS
+#elif HAVE_TERMIO_H
+# include <sys/ioctl.h>
+# include <termio.h>
+# define STTY(fd, termio) ioctl(fd, TCSETA, termio)
+# define GTTY(fd, termio) ioctl(fd, TCGETA, termio)
+# define TEMRIO struct termio
+# define USE_TERMIO
+#elif HAVE_SGTTY_H
+# include <sgtty.h>
+# define STTY(fd, termio) stty(fd, termio)
+# define GTTY(fd, termio) gtty(fd, termio)
+# define TERMIO struct sgttyb
+# define USE_SGTTY
+#endif
