@@ -27,7 +27,7 @@ int unix_setup(void *gpw)
 {
 	int ic, i, k, temp, len;
 	unsigned random;
-	long seed;
+	sword32 seed;
 	char key[9], salt[3], *enciph;
         char *pw=gpw;
 
@@ -115,7 +115,7 @@ int shuffle(char deck[])
 {
 	int i, ic, k, temp;
 	unsigned random;
-	static long seed = 123;
+	static sword32 seed = 123;
 
 	for(i=0;i<ROTORSZ;i++) {
 		seed = 5*seed + cbuf[i%13];
