@@ -27,10 +27,11 @@
 #include "bits.h"
 #include "locks.h"
 #include <errors.h>
+#include <getpass.h>
 
 extern char* outfile;
 extern int stream_flag;
-
+extern int cleanDelete;
 
 
 
@@ -44,7 +45,7 @@ char *btmp;
    Bzero(ztmp,sizeof(ztmp));
    strncat(ztmp,atmp,127);
 
-   btmp=getpass("Re-Enter key: ");
+   btmp=getpass(_("Re-Enter key: "));
    
   if (strcmp(ztmp,btmp)!=0) {
      fprintf(stderr,_("Keywords do not match or they are too long.\n"));
@@ -274,11 +275,19 @@ void shandler(int signal)
 
 }
 
+void snhandler(int signal)
+{
+
+ fprintf(stderr, _("\nSignal %d caught. Exiting.\n"),signal);
+ cleanUp();
+ exit(-1);
+
+}
+
 void cleanUp() {
 
-fflush(NULL);
-if (stream_flag==FALSE) remove(outfile); /* Delete the file we were writing to */
-
+ fflush(NULL);
+ if (stream_flag==FALSE && cleanDelete==TRUE) remove(outfile); /* Delete the file we were writing to */
 
 }
 
@@ -336,3 +345,37 @@ struct passwd* pwd;
 #endif
 
 
+int ask_overwrite(char *name, char * file) {
+char x[2];
+
+#ifdef HAVE_SIGNAL_H
+ Signal( SIGINT , snhandler);
+ Signal( SIGQUIT, snhandler);
+ Signal( SIGSEGV, snhandler);
+ Signal( SIGPIPE, snhandler);
+ Signal( SIGTERM, snhandler);
+ Signal( SIGHUP , snhandler);
+#endif
+         
+
+ fprintf(stderr, _("%s: %s already exists; do you wish to overwrite (y or n)?"), name, file);
+ x[0]=getc(stdin);
+ x[1]='\0';
+
+#ifdef HAVE_SIGNAL_H
+ Signal( SIGINT , shandler);
+ Signal( SIGQUIT, shandler);
+ Signal( SIGSEGV, shandler);
+ Signal( SIGPIPE, shandler);
+ Signal( SIGTERM, shandler);
+ Signal( SIGHUP , shandler);
+#endif
+
+ if (strncmp(x,"y",1)==0 || strncmp(x,"Y",1)==0) {
+  return TRUE;
+ }
+ else {
+  return FALSE;
+ }
+
+}
