@@ -806,7 +806,7 @@ int gaa(int argc, char **argv, gaainfo *gaaval)
 #line 65 "mcrypt.gaa"
 { gaaval->force=0; gaaval->quiet=1; gaaval->real_random_flag=0; gaaval->config=0;
        gaaval->bare_flag = 0; gaaval->din = 0; gaaval->ein=1; gaaval->hexflag = 0; gaaval->unlink_flag = 0;
-       gaaval->bit = 8;
+       gaaval->bit = 8; gaaval->keysize=0;
        gaaval->sunlink_flag = 0; gaaval->keyfile=NULL; gaaval->algorithm=NULL; gaaval->keys=NULL;
        gaaval->config_file=NULL; gaaval->mode=NULL; gaaval->input=NULL; gaaval->ed_specified=0 ;};
 
