@@ -8,16 +8,16 @@ void time_out(int signo);
 #ifdef HAVE_UNISTD_H
 # ifdef HAVE_FCNTL
 struct flock* file_lock(short type, short whence);
-void read_lock(int fd);
-void write_lock(int fd);
-void append_lock(int fd);
+int read_lock(int fd);
+int write_lock(int fd);
+int append_lock(int fd);
 void unlock(int fd);  /* unlock */
 
 # else /* Do nothing */
 void file_lock(short type, short whence);
-void read_lock(int fd);
-void write_lock(int fd);
-void append_lock(int fd);
+int read_lock(int fd);
+int write_lock(int fd);
+int append_lock(int fd);
 void unlock(int fd);
 
 # endif
