@@ -24,6 +24,7 @@
 */
 
 #include <mcrypt.h>
+#include <xmalloc.h>
 #include <xmemory.h>
 #include <bzero.h>
 #include <extra.h>
@@ -49,6 +50,7 @@
  int unlink_flag=FALSE;
  int sunlink_flag=FALSE; 
  int bare_flag=FALSE, real_random_flag=FALSE;
+ int cleanDelete=FALSE;
  char *outfile=0;
 
 void usage(char *name)
@@ -87,7 +89,7 @@ void usage(char *name)
  -h --help                    prints this help\n\
  -v --version                 prints the version number\n\
 \n\
-Report bugs to nmav@i-net.paiko.gr.\n\n"));
+Report bugs to mcrypt@i-net.paiko.gr.\n\n"));
 }
 
 void mcrypt_license() {
@@ -138,7 +140,7 @@ int main(int argc,char **argv)
 #endif 
 
 #ifdef ENABLE_NLS
-  setlocale (LC_MESSAGES, "");
+  setlocale (LC_ALL, "");
   bindtextdomain (PACKAGE, LOCALEDIR);
   textdomain (PACKAGE);
 #endif
@@ -150,7 +152,7 @@ int main(int argc,char **argv)
         }
         
           if (info.config_file!=NULL) {
-            cfile=mxmalloc(strlen(info.config_file));
+            cfile=xmalloc(strlen(info.config_file));
             strcpy(cfile,info.config_file);
             if (check_file(cfile)!=1) {
               err_crit (_("Warning: Cannot access config file.\n"));
@@ -160,7 +162,7 @@ int main(int argc,char **argv)
 #ifdef HAVE_GETPWUID          
             cfile=get_cfile(getuid(), ".mcryptrc");
 #else
-            cfile=mxmalloc(11);
+            cfile=xmalloc(11);
             strcpy(cfile,".mcryptrc");
 #endif          
           }
@@ -216,8 +218,10 @@ int main(int argc,char **argv)
      ein=FALSE;
    }
    else {
+    if(strlen(argv[0])>5) {
      Bzero(argv[0], strlen(argv[0]));
      strcpy( argv[0], "mcrypt");
+    }
      din=FALSE;
      ein=TRUE; /* It will change by the arguments */
    }
@@ -226,7 +230,7 @@ int main(int argc,char **argv)
 
             /* File pointers are as much as the file arguments */
 
-        file=mxmalloc((info.size)*sizeof(char*)); 
+        file=xmalloc((info.size)*sizeof(char*)); 
     
         if (info.ed_specified!=0) {
           din=info.din;
@@ -273,18 +277,18 @@ int main(int argc,char **argv)
                else {
                 if (info.keys!=NULL) {
                  kin=2;
-                 keyfile=mxmalloc(info.keysize * sizeof(char*));
+                 keyfile=xmalloc(info.keysize * sizeof(char*));
                  keys=info.keysize;
                 
                  for (i=0; i<info.keysize; i++) {
-                   keyfile[i]=mxmalloc(strlen(info.keys[i])+10);
+                   keyfile[i]=xmalloc(strlen(info.keys[i])+10);
                    strcpy(keyfile[i],info.keys[i]);
                  }
                 }
                }
 
               if (info.mode!=NULL) {
-		modet= mxmalloc(strlen(info.mode)+1);
+		modet= xmalloc(strlen(info.mode)+1);
 		strcpy(modet,info.mode);
 			if (strncasecmp(modet,"ECB",3)==0) {
 			  mode=ECB;
@@ -309,10 +313,11 @@ int main(int argc,char **argv)
                         }
 			free(modet);
                     }
+
                     
                     if (info.algorithm!=NULL) {
                         used_algo=TRUE;
-			typet= mxmalloc(strlen(info.algorithm)+1);
+			typet= xmalloc(strlen(info.algorithm)+1);
 			strcpy(typet,info.algorithm);
 			if (strncasecmp(typet,"DES",3)==0) {
 			  type=DES;
@@ -464,26 +469,33 @@ for(i=0;i<file_count;i++) {
              
             if (dinfile[y-1]=='c' && dinfile[y-2]=='n' && dinfile[y-3]=='e' && dinfile[y-4]=='.') {
 
-	      outfile= mxcalloc(y-3,1);
+	      outfile= xcalloc(y-3,1);
   	      strncat(outfile,dinfile,y-4);
 #ifdef HAVE_STAT
               /* But if it exists exit */
               if (check_file(outfile)!=0) {
-                sprintf(tmperr, _("%s: file %s exists... skipping...\n"), argv[0], outfile);
-                err_crit (tmperr);
-                continue;
+                cleanDelete=FALSE;
+                if (ask_overwrite(argv[0], outfile)==FALSE) {
+                  continue;
+                }
+                else {
+                  cleanDelete=TRUE;
+                }
+              }
+              else {
+                cleanDelete=TRUE;
               }
 #endif  	      
             }
             else { /* append .dec */
 
-	     outfile=mxcalloc(y+5,1);
+	     outfile=xcalloc(y+5,1);
              strncpy(outfile,dinfile,y);
              strcat(outfile,".dec");
             }
          }
 	 else { /* encryption- append .enc */
-	    outfile= mxcalloc(strlen(einfile)+5,1);
+	    outfile= xcalloc(strlen(einfile)+5,1);
 	    strcpy(outfile,einfile);
             /* if file has already the .enc ignore it */
             if (strstr( outfile, ".enc")!=NULL) {
@@ -496,9 +508,17 @@ for(i=0;i<file_count;i++) {
 #ifdef HAVE_STAT
               /* But if it exists exit */
               if (check_file(outfile)!=0) {
-                sprintf(tmperr, _("%s: file %s exists... skipping...\n"), argv[0], outfile);
-                err_crit (tmperr);
-                continue;
+               cleanDelete=FALSE;
+               if (ask_overwrite(argv[0], outfile)==FALSE) {
+                 continue;
+               }
+               else {
+                 cleanDelete=TRUE;
+               }
+
+              }
+              else {
+                cleanDelete=TRUE;
               }
 #endif  	      
 
@@ -506,7 +526,7 @@ for(i=0;i<file_count;i++) {
        }
        else { /* if streams */
 
-         outfile=mxmalloc(7);
+         outfile=xmalloc(7);
          strcpy(outfile,"stdout");
 
        }
@@ -593,7 +613,12 @@ for(i=0;i<file_count;i++) {
                           if (stream_flag==FALSE) {
                            sprintf(tmperr, _("File %s was NOT decrypted successfully.\n"),dinfile);
                            err_crit (tmperr);
-          	           remove(outfile);
+          	            if (x!=-1) {
+          	              remove(outfile);
+          	            }
+          	            else {
+          	              x=1;
+          	            }
         	          }
         	          else {
         	           err_crit (_("Stdin was NOT decrypted successfully.\n"));
@@ -663,7 +688,12 @@ for(i=0;i<file_count;i++) {
                          if (stream_flag==FALSE) {
                           sprintf(tmperr, _("File %s was NOT encrypted successfully.\n"),einfile);
                           err_crit (tmperr);
-                          remove(outfile);
+          	            if (x!=-1) {
+          	              remove(outfile);
+          	            }
+          	            else {
+          	              x=1;
+          	            }
 	                 }
                          else {
 	                  err_crit (_("Stdin was NOT encrypted successfully.\n"));
@@ -720,8 +750,8 @@ else {
 	if (read_lock( fileno((FILE*)FROMF))==-1) return 1;
 	
 	TOF=fopen(tofile,"wb");
-	if (TOF==NULL) {perror("fopen");return 1;}
-	if (write_lock( fileno((FILE*)TOF))==-1) return 1;
+	if (TOF==NULL) {perror("fopen");return -1;}
+	if (write_lock( fileno((FILE*)TOF))==-1) return -1;
 }
 
          Bzero(keyword,sizeof(keyword));
@@ -821,7 +851,7 @@ int blocksize=get_block_size(algorithm);
 int td;
 
 word32 *IV=0;
-word32 *ciphertext=mxmalloc(blocksize);
+word32 *ciphertext=xmalloc(blocksize);
 FILE * TOF; 
 
  TOF=tmpfile();
@@ -829,7 +859,7 @@ FILE * TOF;
         
 
 if (mode==CBC || mode==CFB) {
- IV=mxmalloc(blocksize);
+ IV=xmalloc(blocksize);
  /* Initialisation Vector */
 
 
@@ -856,8 +886,8 @@ if (mode==CBC || mode==CFB) {
         if (read_lock( fileno((FILE*)FROMF))==-1) return 1;
         
 	RTOF=fopen(tofile,"wb");
-	if (RTOF==NULL) {perror("fopen");return 1;}
-        if (write_lock( fileno((FILE*)RTOF))==-1) return 1;
+	if (RTOF==NULL) {perror("fopen");return -1;}
+        if (write_lock( fileno((FILE*)RTOF))==-1) return -1;
         
   }
 
@@ -1061,7 +1091,7 @@ switch (mode) {
 /* Copy the temporary to RTOF */
 
  fseek(TOF,0,SEEK_SET);
- copychar=mxmalloc(4096);
+ copychar=xmalloc(4096);
 
  do {
     how=fread(copychar, 1, 4096, TOF);
@@ -1127,10 +1157,10 @@ int keysize=get_key_size(algorithm);
 int blocksize=get_block_size(algorithm);
 int td;
 
-word32 *ciphertext_old=mxmalloc(blocksize);
-word32 *buffer=mxmalloc(blocksize);
-word32 *ciphertext=mxmalloc(blocksize);
-word32 *ciphertext_orig=mxmalloc(blocksize);
+word32 *ciphertext_old=xmalloc(blocksize);
+word32 *buffer=xmalloc(blocksize);
+word32 *ciphertext=xmalloc(blocksize);
+word32 *ciphertext_orig=xmalloc(blocksize);
 word32 *keyword;
 
 unsigned int len=0;
@@ -1151,8 +1181,8 @@ else {
         if (read_lock( fileno((FILE*)FROMF))==-1) return 1;
         
 	RTOF=fopen(tofile,"wb");
-	if (RTOF==NULL) {perror("fopen");return 1;}
-        if (write_lock( fileno((FILE*)RTOF))==-1) return 1;
+	if (RTOF==NULL) {perror("fopen");return -1;}
+        if (write_lock( fileno((FILE*)RTOF))==-1) return -1;
 
         if (bare_flag==FALSE) fseek( FROMF, 6, SEEK_CUR);
         /* In streams this has been done when checking for headers. */
